/*********************************************************************
 *  SPDX-License-Identifier: MIT                                     *
 *  Copyright (C) 2007-2023 by Helge Kortendieck  alan@kasmithee.de  *
 *                                                                   *
 *  This file is part of qaplay.                                     *
 *********************************************************************/
#include "abouthelp.h"

AboutHelp::AboutHelp(QDialog* parent)
    : QDialog(parent)
{
	uih.setupUi(&wHelp);
	connect(uih.pB_Close, SIGNAL(clicked()), this, SLOT(closeDlg()));
}

AboutHelp::~AboutHelp()
{
}

void AboutHelp::showAh(int iD)
{
	if (iD == 1) {
		showAbout();
	} else {
		showHelp();
	}
}

void AboutHelp::showAbout()                // show about dialog
{
	sHelp = tr("<html><body>"
				"qaplay - simple audio player, based on Qt6 and gstreamer.<p>"
	            "Version 4.0.6 , (C) 2006-2023 by Helge Kortendieck<p>"
				"This program is released under the MIT license.<br>"
				"</body></html>" );
	uih.tb_Help->setHtml(sHelp);
	wHelp.setWindowTitle(tr("about qaplay"));
	wHelp.showNormal();
	wHelp.resize(610, 200);
	qPos = QCursor::pos();
	iD = qPos.x() - 500;
	if (iD < 0) {
		iD = 0;
	}
	iD2 = qPos.y() - 210;
	if (iD2 < 0) {
		iD2 = 0;
	}
	wHelp.move(iD, iD2);
	wHelp.show();
}

void AboutHelp::showHelp()                 // show help dialog
{
	sHelp = tr("<html><body>"
				"<a name=""Top""><b>Table of content</b></a><br>"
				"<a href=""#Intro"">Introduction</a><br>"
				"<a href=""#Usage"">Starting</a><br>"
				"<a href=""#Options"">Options</a><br>"
				"<a href=""#Faq"">FAQ</a><br>"
				"<a href=""#Credits"">Credits</a><p>"

				"<hr>"
				"<a name=""Intro""><b><u>Introduction</u></b></a><p>"
				"qaplay is a small audio player using the Qt6 toolkit and gstreamer.<br>"
				"It is meant to play audio files by clicking on them in a file manager.<br>"
				"It will generate a list of all audio files in the dir of the selected song and plays the calling song and then to the end of the list.<br>"
				"When invoked with a *.m3u playlist it will try to play the songs in this playlist<br>"
				"An icon is displayed in the system tray, which allows to quit qaplay (stop playing does this currently too - see Usage below...) or to select the previous or next song (if available).<br>"
				"If playing audio file(s) is not stopped, qaplay exits at the end of the last song in the list (it will never play songs above the starting song in a dir - alone!).<br>"
				"However, when selecting next on the last song it will start at the top of the list (again)."
				"qaplay will also play known music files in a directory, if called with the directory name alone.<br>"
				"qaplay will currently exit, if the playing of the current song is stopped.<br>"
				"This might change in the future, once showing the current list of songs to play will be implemented.<br>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Usage""><b><u>Starting</u></b></a><p>"
				"You can either<br>"
				"a) set qaplay as the default player for the audio mime types (the file types/endings) in your file manager for which you want to use it, or<br>"
				"b) right-click on the file to play, choose 'Open with...' and then select qaplay as the player. ('Open with...' or something similar, depending on your file manger).<p>"
				"While the audio file is played, it can be stopped by right-clicking on the icon in the system tray and selecting 'Quit'.<br>"
				"qaplay will silently exit at the end of the last played audio file in the directory of the file qaplay was started with.<p>"
				"When qaplay is set to be the default player for a file type, you can play the file by simply left-clicking on it in the file manager.<br>"
				"Setting a program as the default program for a mime type varies between the different file managers.<br>"
				"An easy way is often to right-click on a file, choose 'Open with...' (or similar) and then check a checkbox with says something like 'set this "
				"program as the default program for this file type' .<br>"
				"If a checkbox like this is not available, it might be possible to set the default program for a mime type in the settings dialog of the file "
				"manager, accessable via a menu entry like 'Settings' or 'Configure'.<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Options""><b><u>Options</u></b></a><p>"
				"None available or needed. qaplay has no GUI, it has to be invoked with a file to play: 'qaplay mysong' !<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Faq""><b><u>FAQ</u></b></a><p>"
				"None so far.<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Credits""><b><u>Credits</u></b></a><p>"
				"Credits & Contributions:<p>"
				"qaplay uses Qt6 and gstreamer.<br>"
				"The program icon:<br>"
				"- qaplay.svg - category_subcategory_music.svg, openclipart.org, uploaded 2015-01-10 by sixsixfive, Public Domain.<br>"
				"Icons used within qaplay:<br>"
				"- about.svg - based on CapA.svg, openclipart.org, uploaded 2016-04-03 by AdamStanislav, Public Domain.<br>"
				"- down.svg - go-down-orange.svg, openclipart.org, uploaded 2012-01-09 by rygle, Public Domain.<br>"
				"- drop.svg - blood-clipart.svg, openclipart.org, uploaded 2011-08-08 by prapanj, Public Domain.<br>"
				"- edit.svg - 1298512738.svg, openclipart.org, uploaded 2011-02-24 by dear_theophilus, Public Domain.<br>"
				"- help.svg - open_icon_library-GPL-0.10, actions/help-contents-3.svg updated by H. Kortendieck (me).<br>"
				"- info.svg - open_icon_library, help-about-3.svg, oxygen, CC-BY-SA 3.0 or LGPL<br>"
//				"- playlist.svg - open_icon_library, view-media-playlist-3.svg, oxygen, CC-BY-SA 3.0 or LGPL<br>"
				"- media-next.svg - based on go-last-orange.svg, openclipart.org, uploaded 2012-01-09 by rygle, Public Domain.<br>"
				"- media-pause.svg - based on go-pause-orange.svg, openclipart.org, uploaded 2012-01-09 by rygle, Public Domain.<br>"
				"- media-play.svg - based on go-next-orange.svg, openclipart.org, uploaded 2012-01-09 by rygle, Public Domain.<br>"
				"- media-previous.svg - based on go-first-orange.svg, openclipart.org, uploaded 2012-01-09 by rygle, Public Domain.<br>"
				"- media-stop.svg - based on stop-orange.svg, openclipart.org, uploaded 2012-01-09 by rygle, Public Domain.<br>"
//				"- next.svg - open_icon_library-GPL-0.10, actions/go-next-view.svg .<br>"
				"- new.svg - matt-icons_document-add.svg, openclipart.org, uploaded 2015-01-10 by sixsixfive, Public Domain.<br>"
				"- open.svg - actions/document-open-5.svg - open icon library version 10 Nov. 2009, tango,PD.<br>"
				"- plAdd.svg - open_icon_library-GPL-0.10, actions/list-add-5.svg .<br>"
				"- plPlay.svg - open_icon_library-GPL-0.10, mimetypes/gnome-style/audio-x-generic-2.svg .<br>"
				"- quit.svg - open_icon_library-GPL-0.10, actions/system-shutdown-6.svg .<br>"
				"- rename.svg - tag.svg, openclipart.org, uploaded 2010-09-06 by jhnri4, Public Domain.<br>"
				"- save-as.svg - actions/document-save-as-5.svg	- open icon library	version 10 Nov. 2009, oxygen,CC-BY-SA 3.0 or LGPL.<br>"
				"- songlist.svg - Monochrome-list-icon.svg, openclipart.org, uploaded 2015-01-28 by SimpleIcons, Public Domain.<br>"
				"- up.svg - go-up-orange.svg, openclipart.org, uploaded 2012-01-09 by rygle, Public Domain.<br>"
	            "Program and documentation Copyright 2006-2023 by Helge Kortendieck.<p>"
				"This program is released under the MIT license.<p>"
				"<a href=""#Top"">back to top</a><p>"
				"</body></html>" );
	uih.tb_Help->setHtml(sHelp);
	wHelp.setWindowTitle(tr("qaplay - help"));
	wHelp.showFullScreen();
	wHelp.show();
}

void AboutHelp::closeDlg()
{
	emit sigAhQapDelete();
}

