/*********************************************************************
 *  SPDX-License-Identifier: MIT                                     *
 *  Copyright (C) 2006-2023 by Helge Kortendieck  alan@kasmithee.de  *
 *                                                                   *
 *  This file is part of qaplay.                                     *
 *********************************************************************/
#include "qaplay.h"

#include <QApplication>
#include <QDir>
#include <QLockFile>
#include <QMessageBox>
#include <QStringList>

#include <iostream>
using namespace std;

int main(int argc, char **argv)
{
  QApplication app(argc, argv);
 
  QLockFile lockFile(QDir::temp().absoluteFilePath("qaplay.lock"));
  
  if (!lockFile.tryLock(100)) {
	QMessageBox msgBox;
	msgBox.setIcon(QMessageBox::Warning);
	msgBox.setText("It seems already another instance of qaplay is running.\n"
				   "Only 1 instance is allowed at a time to avoid sound chaos. :-)\n");
	msgBox.setInformativeText("In case of a leftover (after a crash?) you may want to manually "
							  "delete the file   qaplay.lock   in your temporary directory.");
	int ret = msgBox.exec();
	return 1;
  }
  
  app.setQuitOnLastWindowClosed(false);
  QStringList slArgs = QApplication::arguments();  // get command line args
  int iArgs = slArgs.count();

  if(iArgs != 2) {
    cout << "###  qaplay - Qt6 based audio player using gstreamer\n"
	        "###  Intended to play sounds by clicking on them in a GUI file manager.\n"
            "###  Adds a stop button in the system tray to allow to\n"
            "###  stop playing the current sound.\n"
            "###  Creates a playlist of all files in the dir a song is started.\n"
            "###  Allows to select previous/next song, to select from the play list\n"
            "###  and add to a favorite playlist (and play this one).\n"
            "###  \n"
	        "###  Version 4.0.6\n"
	        "###  Copyright (C) 2006-2023 by Helge Kortendieck, alan@kasmithee.de\n"
            "###  Released under the MIT license\n"
            "###  \n"
            "###  Use 'man qaplay' to see a short program description.\n"
            "###  \n"
            "###  This program requires Qt6, X11/wayland and a systemtray.\n"
            "###  Start the program with exact 1 argument:\n"
            "###  the full path and name to the audio file to play.\n"
            "###  While running, right click on the tray icon and\n"
            "###  select the online help to learn more about qaplay.\n" << endl;
    return 0;
  };

  Qaplay qplayer;
  qplayer.show();
  return app.exec();
}
